==> LL_utils-4.1.1.4-power-Linux-RHEL6.tar.gz: var/www/ll/cgi-bin/on_delete.pl <==
#!/usr/bin/perl

# static char sccsid[] = "@(#)19 1.8 src/ll/config_editor/cgi-bin/on_delete.pl, ll.config, ll_rrur2, rrur21042a 11/6/09 01:31:40\n";

use strict;
use lib "/var/www/ll/cgi-bin";
use LLUtil;
use DBI;

my ($mysql_host, $mysql_user, $mysql_pass, $mysql_db) = get_db_info(0);

my $query = $ENV{QUERY_STRING};
$query = unescape($query);

debug_log($query);
$_ = $query;
if(/panel=(.+)&id=(\d+)/)
{
	my $json_str = "Content-type: text/html\n\n";

	my $dbh = DBI->connect("DBI:mysql:database=$mysql_db;host=$mysql_host",$mysql_user,$mysql_pass);
	if(!defined($dbh))
	{
		$json_str .= DBI->errstr;
		print $json_str;		
		exit 1;
	}
	
	my $sql_str;
	if($1 eq "tab_panel_classes")
	{
		$sql_str = "delete from TLLS_CFGClass where classID = ".$2;
		debug_log($sql_str);
	}
	elsif($1 eq "tab_panel_groups")
	{
		$sql_str = "delete from TLLS_CFGGroup where groupID = ".$2;
		debug_log($sql_str);
	}
	elsif($1 eq "tab_panel_machines")
	{
		$sql_str = "delete from TLL_Nodelist where nodeID = ".$2;
		debug_log($sql_str);		
	}
	elsif($1 eq "tab_panel_machine_groups")
	{
		$sql_str = "delete from TLL_MachineGroup where mgID = ".$2;
		debug_log($sql_str);		
	}
	elsif($1 eq "tab_panel_region")
	{
		$sql_str = "delete from TLLR_CFGRegion where regionID = ".$2;
		debug_log($sql_str);		
	}
	elsif($1 eq "tab_panel_multicluster")
	{
		$sql_str = "delete from TLL_Cluster where clusterID = ".$2;
		debug_log($sql_str);
	}
	elsif($1 eq "tab_panel_users")
	{
		$sql_str = "delete from TLLS_CFGUser where userID = ".$2;
		debug_log($sql_str);
	}
	else
	{
	}

	if(defined($dbh->do($sql_str)))
	{
		$json_str .= "OK";
	}
	else
	{
		$json_str .= $dbh->errstr;
	}

	$dbh->disconnect();

	print $json_str;	

}

==> LL_utils-5.1.0.17-power-Linux-RHEL6.tar.gz: var/www/ll/cgi-bin/on_delete.pl <==
#!/usr/bin/perl

# static char sccsid[] = "@(#)19 1.9 src/ll/config_editor/cgi-bin/on_delete.pl, ll.config, ll_rrnep2, rrnep21206a 9/26/10 16:07:01\n";

use strict;
use lib "/var/www/ll/cgi-bin";
use LLUtil;
use DBI;

my ($db_host, $db_user, $db_pass, $db_db, $db_conn, $db2inst) = get_db_info(0);

my $query = $ENV{QUERY_STRING};
$query = unescape($query);

debug_log($query);
$_ = $query;
if(/panel=(.+)&id=(\d+)/)
{
	my $json_str = "Content-type: text/html\n\n";

	my $dbh = get_dbh(0);
	if(!defined($dbh))
	{
		error_and_exit($dbh->errstr);
	}
	
	my $sql_str;
	if($1 eq "tab_panel_classes")
	{
		$sql_str = "delete from TLLS_CFGClass where classID = ".$2;
		debug_log($sql_str);
	}
	elsif($1 eq "tab_panel_groups")
	{
		$sql_str = "delete from TLLS_CFGGroup where groupID = ".$2;
		debug_log($sql_str);
	}
	elsif($1 eq "tab_panel_machines")
	{
		$sql_str = "delete from TLL_Nodelist where nodeID = ".$2;
		debug_log($sql_str);		
	}
	elsif($1 eq "tab_panel_machine_groups")
	{
		$sql_str = "delete from TLL_MachineGroup where mgID = ".$2;
		debug_log($sql_str);		
	}
	elsif($1 eq "tab_panel_region")
	{
		$sql_str = "delete from TLLR_CFGRegion where regionID = ".$2;
		debug_log($sql_str);		
	}
	elsif($1 eq "tab_panel_multicluster")
	{
		$sql_str = "delete from TLL_Cluster where clusterID = ".$2;
		debug_log($sql_str);
	}
	elsif($1 eq "tab_panel_users")
	{
		$sql_str = "delete from TLLS_CFGUser where userID = ".$2;
		debug_log($sql_str);
	}
	else
	{
	}

	if(defined($dbh->do($sql_str)))
	{
		$json_str .= "OK";
	}
	else
	{
		$json_str .= $dbh->errstr;
	}

	$dbh->disconnect();

	print $json_str;	

}
